{% from "geoserver/map.jinja" import geoserver with context %}

geoserver_home:
  file.directory:
    - name: {{ geoserver.root }}
    - user: root
    - group: wheel
    - mode: 755

pkg_sudo:
  pkg.installed:
    - name: sudo

{% for instance, config in geoserver.instances.items() %}

{{ instance }}_jdk_pkg:
  pkg.installed:
    - name: {{ config.jdk_conf.pkg }}
    - require:
      - pkg: pkg_sudo

#############
# GEOSERVER #
#############

{{ instance }}_geoserver_archive:
  archive.extracted:
    - name: {{ config.root | path_join('geoserver-' ~ config.version) }}
    - user: {{ config.user }}
    - group: {{ config.group }}
    - source: {{ config.source }}
    - source_hash: {{ config.source_hash }}
    - enforce_toplevel: False
    - require:
      - file: geoserver_home
      - pkg: {{ instance }}_jdk_pkg
    - unless:
      - fun: file.directory_exists
        path: {{ config.GEOSERVER_HOME }}
  file.rename:
    - name: {{ config.GEOSERVER_HOME|path_join('webapps', 'ROOT') }}
    - source: {{ config.GEOSERVER_HOME|path_join('webapps', 'geoserver') }}
    - require:
      - archive: {{ instance }}_geoserver_archive

{{ instance }}_geoserver_web_xml:
  file.line:
    - name: {{ config.web_xml }}
    - content: |
        <!-- START managed_resource_ref -->
        <!-- END managed_resource_ref -->
    - mode: ensure
    - before: </web-app>
    - indent: False
    - unless:
      - fun: file.search
        path: {{ config.web_xml }}
        pattern: '<!-- START managed_resource_ref -->'
    - require:
      - file: {{ instance }}_geoserver_archive

###############
# PERMISSIONS #
###############

{{ instance }}_geoserver_fix_bin:
  file.directory:
    - name: {{ config.bin_dir }}
    - user: {{ config.user }}
    - group: {{ config.group }}
    - file_mode: 755
    - recurse:
      - user
      - group
      - mode
    - require:
      - archive: {{ instance }}_geoserver_archive

{{ instance }}_log:
  file.managed:
    - name: {{ config.log }}
    - user: {{ config.user }}
    - group: {{ config.group }}
    - mode: 644
    - makedirs: True

{% endfor %}
